/*******************************************************************************
* File Name: PinOutB.c  
* Version 2.5
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PinOutB.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        PinOutB_PC =   (PinOutB_PC & \
                                (uint32)(~(uint32)(PinOutB_DRIVE_MODE_IND_MASK << (PinOutB_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (PinOutB_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: PinOutB_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void PinOutB_Write(uint8 value) 
{
    uint8 drVal = (uint8)(PinOutB_DR & (uint8)(~PinOutB_MASK));
    drVal = (drVal | ((uint8)(value << PinOutB_SHIFT) & PinOutB_MASK));
    PinOutB_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: PinOutB_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  PinOutB_DM_STRONG     Strong Drive 
*  PinOutB_DM_OD_HI      Open Drain, Drives High 
*  PinOutB_DM_OD_LO      Open Drain, Drives Low 
*  PinOutB_DM_RES_UP     Resistive Pull Up 
*  PinOutB_DM_RES_DWN    Resistive Pull Down 
*  PinOutB_DM_RES_UPDWN  Resistive Pull Up/Down 
*  PinOutB_DM_DIG_HIZ    High Impedance Digital 
*  PinOutB_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void PinOutB_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(PinOutB__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: PinOutB_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PinOutB_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PinOutB_Read(void) 
{
    return (uint8)((PinOutB_PS & PinOutB_MASK) >> PinOutB_SHIFT);
}


/*******************************************************************************
* Function Name: PinOutB_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PinOutB_ReadDataReg(void) 
{
    return (uint8)((PinOutB_DR & PinOutB_MASK) >> PinOutB_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PinOutB_INTSTAT) 

    /*******************************************************************************
    * Function Name: PinOutB_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PinOutB_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(PinOutB_INTSTAT & PinOutB_MASK);
		PinOutB_INTSTAT = maskedStatus;
        return maskedStatus >> PinOutB_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
