/*******************************************************************************
* File Name: SCBUART_PINS.h
* Version 1.20
*
* Description:
*  This file provides constants and parameter values for the pin components
*  buried into SCB Component.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_PINS_SCBUART_H)
#define CY_SCB_PINS_SCBUART_H

#include "cydevice_trm.h"
#include "cyfitter.h"
#include "cytypes.h"


/***************************************
*   Conditional Compilation Parameters
****************************************/

/* Unconfigured pins */
#define SCBUART_REMOVE_MOSI_SCL_RX_WAKE_PIN    (1u)
#define SCBUART_REMOVE_MOSI_SCL_RX_PIN         (1u)
#define SCBUART_REMOVE_MISO_SDA_TX_PIN         (1u)
#define SCBUART_REMOVE_SCLK_PIN                (1u)
#define SCBUART_REMOVE_SS0_PIN                 (1u)
#define SCBUART_REMOVE_SS1_PIN                 (1u)
#define SCBUART_REMOVE_SS2_PIN                 (1u)
#define SCBUART_REMOVE_SS3_PIN                 (1u)

/* Mode defined pins */
#define SCBUART_REMOVE_I2C_PINS                (1u)
#define SCBUART_REMOVE_SPI_MASTER_PINS         (1u)
#define SCBUART_REMOVE_SPI_SLAVE_PINS          (1u)
#define SCBUART_REMOVE_SPI_MASTER_SS0_PIN      (1u)
#define SCBUART_REMOVE_SPI_MASTER_SS1_PIN      (1u)
#define SCBUART_REMOVE_SPI_MASTER_SS2_PIN      (1u)
#define SCBUART_REMOVE_SPI_MASTER_SS3_PIN      (1u)
#define SCBUART_REMOVE_UART_TX_PIN             (0u)
#define SCBUART_REMOVE_UART_RX_TX_PIN          (1u)
#define SCBUART_REMOVE_UART_RX_PIN             (0u)
#define SCBUART_REMOVE_UART_RX_WAKE_PIN        (1u)

/* Unconfigured pins */
#define SCBUART_MOSI_SCL_RX_WAKE_PIN   (0u == SCBUART_REMOVE_MOSI_SCL_RX_WAKE_PIN)
#define SCBUART_MOSI_SCL_RX_PIN        (0u == SCBUART_REMOVE_MOSI_SCL_RX_PIN)
#define SCBUART_MISO_SDA_TX_PIN        (0u == SCBUART_REMOVE_MISO_SDA_TX_PIN)
#define SCBUART_SCLK_PIN               (0u == SCBUART_REMOVE_SCLK_PIN)
#define SCBUART_SS0_PIN                (0u == SCBUART_REMOVE_SS0_PIN)
#define SCBUART_SS1_PIN                (0u == SCBUART_REMOVE_SS1_PIN)
#define SCBUART_SS2_PIN                (0u == SCBUART_REMOVE_SS2_PIN)
#define SCBUART_SS3_PIN                (0u == SCBUART_REMOVE_SS3_PIN)

/* Mode defined pins */
#define SCBUART_I2C_PINS               (0u == SCBUART_REMOVE_I2C_PINS)
#define SCBUART_SPI_MASTER_PINS        (0u == SCBUART_REMOVE_SPI_MASTER_PINS)
#define SCBUART_SPI_SLAVE_PINS         (0u == SCBUART_REMOVE_SPI_SLAVE_PINS)
#define SCBUART_SPI_MASTER_SS0_PIN     (0u == SCBUART_REMOVE_SPI_MASTER_SS0_PIN)
#define SCBUART_SPI_MASTER_SS1_PIN     (0u == SCBUART_REMOVE_SPI_MASTER_SS1_PIN)
#define SCBUART_SPI_MASTER_SS2_PIN     (0u == SCBUART_REMOVE_SPI_MASTER_SS2_PIN)
#define SCBUART_SPI_MASTER_SS3_PIN     (0u == SCBUART_REMOVE_SPI_MASTER_SS3_PIN)
#define SCBUART_UART_TX_PIN            (0u == SCBUART_REMOVE_UART_TX_PIN)
#define SCBUART_UART_RX_TX_PIN         (0u == SCBUART_REMOVE_UART_RX_TX_PIN)
#define SCBUART_UART_RX_PIN            (0u == SCBUART_REMOVE_UART_RX_PIN)
#define SCBUART_UART_RX_WAKE_PIN       (0u == SCBUART_REMOVE_UART_RX_WAKE_PIN)


/***************************************
*             Includes
****************************************/

#if(SCBUART_MOSI_SCL_RX_WAKE_PIN)
    #include "SCBUART_spi_mosi_i2c_scl_uart_rx_wake.h"
#endif /* (SCBUART_MOSI_SCL_RX_WAKE_PIN) */

#if(SCBUART_MOSI_SCL_RX_PIN)
    #include "SCBUART_spi_mosi_i2c_scl_uart_rx.h"
#endif /* (SCBUART_MOSI_SCL_RX_PIN) */

#if(SCBUART_MISO_SDA_TX_PIN)
    #include "SCBUART_spi_miso_i2c_sda_uart_tx.h"
#endif /* (SCBUART_MISO_SDA_TX_PIN_PIN) */

#if(SCBUART_SCLK_PIN)
    #include "SCBUART_spi_sclk.h"
#endif /* (SCBUART_SCLK_PIN) */

#if(SCBUART_SS0_PIN)
    #include "SCBUART_spi_ss0.h"
#endif /* (SCBUART_SS1_PIN) */

#if(SCBUART_SS1_PIN)
    #include "SCBUART_spi_ss1.h"
#endif /* (SCBUART_SS1_PIN) */

#if(SCBUART_SS2_PIN)
    #include "SCBUART_spi_ss2.h"
#endif /* (SCBUART_SS2_PIN) */

#if(SCBUART_SS3_PIN)
    #include "SCBUART_spi_ss3.h"
#endif /* (SCBUART_SS3_PIN) */

#if(SCBUART_I2C_PINS)
    #include "SCBUART_scl.h"
    #include "SCBUART_sda.h"
#endif /* (SCBUART_I2C_PINS) */

#if(SCBUART_SPI_MASTER_PINS)
    #include "SCBUART_sclk_m.h"
    #include "SCBUART_mosi_m.h"
    #include "SCBUART_miso_m.h"
#endif /* (SCBUART_SPI_MASTER_PINS) */

#if(SCBUART_SPI_SLAVE_PINS)
    #include "SCBUART_sclk_s.h"
    #include "SCBUART_mosi_s.h"
    #include "SCBUART_miso_s.h"
    #include "SCBUART_ss_s.h"
#endif /* (SCBUART_SPI_SLAVE_PINS) */

#if(SCBUART_SPI_MASTER_SS0_PIN)
    #include "SCBUART_ss0_m.h"
#endif /* (SCBUART_SPI_MASTER_SS0_PIN) */

#if(SCBUART_SPI_MASTER_SS1_PIN)
    #include "SCBUART_ss1_m.h"
#endif /* (SCBUART_SPI_MASTER_SS1_PIN) */

#if(SCBUART_SPI_MASTER_SS2_PIN)
    #include "SCBUART_ss2_m.h"
#endif /* (SCBUART_SPI_MASTER_SS2_PIN) */

#if(SCBUART_SPI_MASTER_SS3_PIN)
    #include "SCBUART_ss3_m.h"
#endif /* (SCBUART_SPI_MASTER_SS3_PIN) */

#if(SCBUART_UART_TX_PIN)
    #include "SCBUART_tx.h"
#endif /* (SCBUART_UART_TX_PIN) */

#if(SCBUART_UART_RX_TX_PIN)
    #include "SCBUART_rx_tx.h"
#endif /* (SCBUART_UART_RX_TX_PIN) */

#if(SCBUART_UART_RX_PIN)
    #include "SCBUART_rx.h"
#endif /* (SCBUART_UART_RX_PIN) */

#if(SCBUART_UART_RX_WAKE_PIN)
    #include "SCBUART_rx_wake.h"
#endif /* (SCBUART_UART_RX_WAKE_PIN) */


/***************************************
*              Registers
***************************************/

#if(SCBUART_MOSI_SCL_RX_WAKE_PIN)
    #define SCBUART_MOSI_SCL_RX_WAKE_HSIOM_REG  \
                                                (*(reg32 *) SCBUART_spi_mosi_i2c_scl_uart_rx_wake__0__HSIOM)
    #define SCBUART_MOSI_SCL_RX_WAKE_HSIOM_PTR  \
                                                ( (reg32 *) SCBUART_spi_mosi_i2c_scl_uart_rx_wake__0__HSIOM)
    #define SCBUART_MOSI_SCL_RX_WAKE_HSIOM_MASK \
                                                (SCBUART_spi_mosi_i2c_scl_uart_rx_wake__0__HSIOM_MASK)
    #define SCBUART_MOSI_SCL_RX_WAKE_HSIOM_POS  \
                                                (SCBUART_spi_mosi_i2c_scl_uart_rx_wake__0__HSIOM_SHIFT)

    #define SCBUART_MOSI_SCL_RX_WAKE_INTCFG_REG    (*(reg32 *) \
                                                              SCBUART_spi_mosi_i2c_scl_uart_rx_wake__0__INTCFG)
    #define SCBUART_MOSI_SCL_RX_WAKE_INTCFG_PTR    ( (reg32 *) \
                                                              SCBUART_spi_mosi_i2c_scl_uart_rx_wake__0__INTCFG)

    #define SCBUART_INTCFG_TYPE_MASK                  (0x03u)
    #define SCBUART_MOSI_SCL_RX_WAKE_INTCFG_TYPE_POS  (SCBUART_spi_mosi_i2c_scl_uart_rx_wake__SHIFT)
    #define SCBUART_MOSI_SCL_RX_WAKE_INTCFG_TYPE_MASK ((uint32)                                           \
                                                                    ((uint32) SCBUART_INTCFG_TYPE_MASK << \
                                                                    SCBUART_MOSI_SCL_RX_WAKE_INTCFG_TYPE_POS))
#endif /* (SCBUART_MOSI_SCL_RX_WAKE_PIN) */

#if(SCBUART_MOSI_SCL_RX_PIN)
    #define SCBUART_MOSI_SCL_RX_HSIOM_REG      (*(reg32 *) SCBUART_spi_mosi_i2c_scl_uart_rx__0__HSIOM)
    #define SCBUART_MOSI_SCL_RX_HSIOM_PTR      ( (reg32 *) SCBUART_spi_mosi_i2c_scl_uart_rx__0__HSIOM)
    #define SCBUART_MOSI_SCL_RX_HSIOM_MASK     (SCBUART_spi_mosi_i2c_scl_uart_rx__0__HSIOM_MASK)
    #define SCBUART_MOSI_SCL_RX_HSIOM_POS      (SCBUART_spi_mosi_i2c_scl_uart_rx__0__HSIOM_SHIFT)
#endif /* (SCBUART_MOSI_SCL_RX_PIN) */

#if(SCBUART_MISO_SDA_TX_PIN)
    #define SCBUART_MISO_SDA_TX_HSIOM_REG      (*(reg32 *) SCBUART_spi_miso_i2c_sda_uart_tx__0__HSIOM)
    #define SCBUART_MISO_SDA_TX_HSIOM_PTR      ( (reg32 *) SCBUART_spi_miso_i2c_sda_uart_tx__0__HSIOM)
    #define SCBUART_MISO_SDA_TX_HSIOM_MASK     (SCBUART_spi_miso_i2c_sda_uart_tx__0__HSIOM_MASK)
    #define SCBUART_MISO_SDA_TX_HSIOM_POS      (SCBUART_spi_miso_i2c_sda_uart_tx__0__HSIOM_SHIFT)
#endif /* (SCBUART_MISO_SDA_TX_PIN_PIN) */

#if(SCBUART_SCLK_PIN)
    #define SCBUART_SCLK_HSIOM_REG     (*(reg32 *) SCBUART_spi_sclk__0__HSIOM)
    #define SCBUART_SCLK_HSIOM_PTR     ( (reg32 *) SCBUART_spi_sclk__0__HSIOM)
    #define SCBUART_SCLK_HSIOM_MASK    (SCBUART_spi_sclk__0__HSIOM_MASK)
    #define SCBUART_SCLK_HSIOM_POS     (SCBUART_spi_sclk__0__HSIOM_SHIFT)
#endif /* (SCBUART_SCLK_PIN) */

#if(SCBUART_SS0_PIN)
    #define SCBUART_SS0_HSIOM_REG      (*(reg32 *) SCBUART_spi_ss0__0__HSIOM)
    #define SCBUART_SS0_HSIOM_PTR      ( (reg32 *) SCBUART_spi_ss0__0__HSIOM)
    #define SCBUART_SS0_HSIOM_MASK     (SCBUART_spi_ss0__0__HSIOM_MASK)
    #define SCBUART_SS0_HSIOM_POS      (SCBUART_spi_ss0__0__HSIOM_SHIFT)
#endif /* (SCBUART_SS1_PIN) */

#if(SCBUART_SS1_PIN)
    #define SCBUART_SS1_HSIOM_REG      (*(reg32 *) SCBUART_spi_ss1__0__HSIOM)
    #define SCBUART_SS1_HSIOM_PTR      ( (reg32 *) SCBUART_spi_ss1__0__HSIOM)
    #define SCBUART_SS1_HSIOM_MASK     (SCBUART_spi_ss1__0__HSIOM_MASK)
    #define SCBUART_SS1_HSIOM_POS      (SCBUART_spi_ss1__0__HSIOM_SHIFT)
#endif /* (SCBUART_SS1_PIN) */

#if(SCBUART_SS2_PIN)
    #define SCBUART_SS2_HSIOM_REG     (*(reg32 *) SCBUART_spi_ss2__0__HSIOM)
    #define SCBUART_SS2_HSIOM_PTR     ( (reg32 *) SCBUART_spi_ss2__0__HSIOM)
    #define SCBUART_SS2_HSIOM_MASK    (SCBUART_spi_ss2__0__HSIOM_MASK)
    #define SCBUART_SS2_HSIOM_POS     (SCBUART_spi_ss2__0__HSIOM_SHIFT)
#endif /* (SCBUART_SS2_PIN) */

#if(SCBUART_SS3_PIN)
    #define SCBUART_SS3_HSIOM_REG     (*(reg32 *) SCBUART_spi_ss3__0__HSIOM)
    #define SCBUART_SS3_HSIOM_PTR     ( (reg32 *) SCBUART_spi_ss3__0__HSIOM)
    #define SCBUART_SS3_HSIOM_MASK    (SCBUART_spi_ss3__0__HSIOM_MASK)
    #define SCBUART_SS3_HSIOM_POS     (SCBUART_spi_ss3__0__HSIOM_SHIFT)
#endif /* (SCBUART_SS3_PIN) */

#if(SCBUART_I2C_PINS)
    #define SCBUART_SCL_HSIOM_REG     (*(reg32 *) SCBUART_scl__0__HSIOM)
    #define SCBUART_SCL_HSIOM_PTR     ( (reg32 *) SCBUART_scl__0__HSIOM)
    #define SCBUART_SCL_HSIOM_MASK    (SCBUART_scl__0__HSIOM_MASK)
    #define SCBUART_SCL_HSIOM_POS     (SCBUART_scl__0__HSIOM_SHIFT)

    #define SCBUART_SDA_HSIOM_REG     (*(reg32 *) SCBUART_sda__0__HSIOM)
    #define SCBUART_SDA_HSIOM_PTR     ( (reg32 *) SCBUART_sda__0__HSIOM)
    #define SCBUART_SDA_HSIOM_MASK    (SCBUART_sda__0__HSIOM_MASK)
    #define SCBUART_SDA_HSIOM_POS     (SCBUART_sda__0__HSIOM_SHIFT)
#endif /* (SCBUART_I2C_PINS) */


/***************************************
*        Registers Constants
***************************************/

/* Pins constants */
#define SCBUART_HSIOM_DEF_SEL      (0x00u)
#define SCBUART_HSIOM_GPIO_SEL     (0x00u)
#define SCBUART_HSIOM_UART_SEL     (0x09u)
#define SCBUART_HSIOM_I2C_SEL      (0x0Eu)
#define SCBUART_HSIOM_SPI_SEL      (0x0Fu)

#if(!SCBUART_CY_SCBIP_V1_I2C_ONLY)
    #define SCBUART_SCB_PINS_NUMBER    (7u)
#else
    #define SCBUART_SCB_PINS_NUMBER    (2u)
#endif /* (!SCBUART_CY_SCBIP_V1_I2C_ONLY) */

#define SCBUART_MOSI_SCL_RX_PIN_INDEX      (0u) /* RX pins without interrupt */
#define SCBUART_MOSI_SCL_RX_WAKE_PIN_INDEX (0u) /* RX pin with interrupt     */
#define SCBUART_MISO_SDA_TX_PIN_INDEX      (1u)
#define SCBUART_SCLK_PIN_INDEX             (2u)
#define SCBUART_SS0_PIN_INDEX              (3u)
#define SCBUART_SS1_PIN_INDEX              (4u)
#define SCBUART_SS2_PIN_INDEX              (5u)
#define SCBUART_SS3_PIN_INDEX              (6u)

#define SCBUART_MOSI_SCL_RX_PIN_MASK      ((uint32) 0x01u << SCBUART_MOSI_SCL_RX_PIN_INDEX)
#define SCBUART_MOSI_SCL_RX_WAKE_PIN_MASK ((uint32) 0x01u << SCBUART_MOSI_SCL_RX_WAKE_PIN_INDEX)
#define SCBUART_MISO_SDA_TX_PIN_MASK      ((uint32) 0x01u << SCBUART_MISO_SDA_TX_PIN_INDEX)
#define SCBUART_SCLK_PIN_MASK             ((uint32) 0x01u << SCBUART_SCLK_PIN_INDEX)
#define SCBUART_SS0_PIN_MASK              ((uint32) 0x01u << SCBUART_SS0_PIN_INDEX)
#define SCBUART_SS1_PIN_MASK              ((uint32) 0x01u << SCBUART_SS1_PIN_INDEX)
#define SCBUART_SS2_PIN_MASK              ((uint32) 0x01u << SCBUART_SS2_PIN_INDEX)
#define SCBUART_SS3_PIN_MASK              ((uint32) 0x01u << SCBUART_SS3_PIN_INDEX)

#define SCBUART_INTCFG_TYPE_FALLING_EDGE   (0x02u)

/* Pin DM defines */
#define SCBUART_PIN_DM_ALG_HIZ  (0u)
#define SCBUART_PIN_DM_DIG_HIZ  (1u)
#define SCBUART_PIN_DM_OD_LO    (4u)
#define SCBUART_PIN_DM_STRONG   (6u)


/***************************************
*          Macro Definitions
***************************************/

/* Set bits-mask in register */
#define SCBUART_SET_REGISTER_BITS(reg, mask, pos, mode) \
                    do                                           \
                    {                                            \
                        (reg) = (((reg) & ((uint32) ~(uint32) (mask))) | ((uint32) ((uint32) (mode) << (pos)))); \
                    }while(0)

/* Set bit the in register */
#define SCBUART_SET_REGISTER_BIT(reg, mask, val) \
                    ((val) ? ((reg) |= (mask)) : ((reg) &= ((uint32) ~((uint32) (mask)))))

#define SCBUART_SET_HSIOM_SEL(reg, mask, pos, sel) SCBUART_SET_REGISTER_BITS(reg, mask, pos, sel)
#define SCBUART_SET_INCFG_TYPE(reg, mask, pos, intType) \
                                                        SCBUART_SET_REGISTER_BITS(reg, mask, pos, intType)
#define SCBUART_SET_INP_DIS(reg, mask, val) SCBUART_SET_REGISTER_BIT(reg, mask, val)

/* SCBUART_SET_I2C_SCL_DR(val) - Sets I2C SCL DR register.
*  SCBUART_SET_I2C_SCL_HSIOM_SEL(sel) - Sets I2C SCL HSIOM settings.
*/
/* SCB I2C: scl signal */
#if(SCBUART_I2C_PINS)
    #define SCBUART_SET_I2C_SCL_DR(val) SCBUART_scl_Write(val)

    #define SCBUART_SET_I2C_SCL_HSIOM_SEL(sel) \
                          SCBUART_SET_HSIOM_SEL(SCBUART_SCL_HSIOM_REG,  \
                                                         SCBUART_SCL_HSIOM_MASK, \
                                                         SCBUART_SCL_HSIOM_POS,  \
                                                         (sel))
    #define SCBUART_WAIT_SCL_SET_HIGH  (0u == SCBUART_scl_Read())

/* Unconfigured SCB: scl signal */
#elif(SCBUART_MOSI_SCL_RX_WAKE_PIN)
    #define SCBUART_SET_I2C_SCL_DR(val) \
                            SCBUART_spi_mosi_i2c_scl_uart_rx_wake_Write(val)

    #define SCBUART_SET_I2C_SCL_HSIOM_SEL(sel) \
                    SCBUART_SET_HSIOM_SEL(SCBUART_MOSI_SCL_RX_WAKE_HSIOM_REG,  \
                                                   SCBUART_MOSI_SCL_RX_WAKE_HSIOM_MASK, \
                                                   SCBUART_MOSI_SCL_RX_WAKE_HSIOM_POS,  \
                                                   (sel))

    #define SCBUART_WAIT_SCL_SET_HIGH  (0u == SCBUART_spi_mosi_i2c_scl_uart_rx_wake_Read())

#elif(SCBUART_MOSI_SCL_RX_PIN)
    #define SCBUART_SET_I2C_SCL_DR(val) \
                            SCBUART_spi_mosi_i2c_scl_uart_rx_Write(val)


    #define SCBUART_SET_I2C_SCL_HSIOM_SEL(sel) \
                            SCBUART_SET_HSIOM_SEL(SCBUART_MOSI_SCL_RX_HSIOM_REG,  \
                                                           SCBUART_MOSI_SCL_RX_HSIOM_MASK, \
                                                           SCBUART_MOSI_SCL_RX_HSIOM_POS,  \
                                                           (sel))

    #define SCBUART_WAIT_SCL_SET_HIGH  (0u == SCBUART_spi_mosi_i2c_scl_uart_rx_Read())

#else
    #define SCBUART_SET_I2C_SCL_DR(val) \
                                                    do{ ; }while(0)
    #define SCBUART_SET_I2C_SCL_HSIOM_SEL(sel) \
                                                    do{ ; }while(0)

    #define SCBUART_WAIT_SCL_SET_HIGH  (0u)
#endif /* (SCBUART_MOSI_SCL_RX_PIN) */

/* SCB I2C: sda signal */
#if(SCBUART_I2C_PINS)
    #define SCBUART_WAIT_SDA_SET_HIGH  (0u == SCBUART_sda_Read())

/* Unconfigured SCB: sda signal */
#elif(SCBUART_MISO_SDA_TX_PIN)
    #define SCBUART_WAIT_SDA_SET_HIGH  (0u == SCBUART_spi_miso_i2c_sda_uart_tx_Read())

#else
    #define SCBUART_WAIT_SDA_SET_HIGH  (0u)
#endif /* (SCBUART_MOSI_SCL_RX_PIN) */

#endif /* (CY_SCB_PINS_SCBUART_H) */


/* [] END OF FILE */
