/*******************************************************************************
* File Name: SCBUART_SPI_UART.h
* Version 1.20
*
* Description:
*  This file provides constants and parameter values for the SCB Component in
*  SPI and UART modes.
*
* Note:
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_SPI_UART_SCBUART_H)
#define CY_SCB_SPI_UART_SCBUART_H

#include "SCBUART.h"


/***************************************
*   SPI Initial Parameter Constants
****************************************/

#define SCBUART_SPI_MODE                   (0u)
#define SCBUART_SPI_SUB_MODE               (0u)
#define SCBUART_SPI_CLOCK_MODE             (0u)
#define SCBUART_SPI_OVS_FACTOR             (16u)
#define SCBUART_SPI_MEDIAN_FILTER_ENABLE   (0u)
#define SCBUART_SPI_LATE_MISO_SAMPLE_ENABLE (0u)
#define SCBUART_SPI_RX_DATA_BITS_NUM       (8u)
#define SCBUART_SPI_TX_DATA_BITS_NUM       (8u)
#define SCBUART_SPI_WAKE_ENABLE            (0u)
#define SCBUART_SPI_BITS_ORDER             (1u)
#define SCBUART_SPI_TRANSFER_SEPARATION    (1u)
#define SCBUART_SPI_NUMBER_OF_SS_LINES     (1u)
#define SCBUART_SPI_RX_BUFFER_SIZE         (8u)
#define SCBUART_SPI_TX_BUFFER_SIZE         (8u)

#define SCBUART_SPI_INTERRUPT_MODE         (0u)

#define SCBUART_SPI_INTR_RX_MASK           (0u)
#define SCBUART_SPI_INTR_TX_MASK           (0u)

#define SCBUART_SPI_RX_TRIGGER_LEVEL       (7u)
#define SCBUART_SPI_TX_TRIGGER_LEVEL       (0u)


/***************************************
*   UART Initial Parameter Constants
****************************************/

#define SCBUART_UART_SUB_MODE              (0u)
#define SCBUART_UART_DIRECTION             (3u)
#define SCBUART_UART_DATA_BITS_NUM         (8u)
#define SCBUART_UART_PARITY_TYPE           (2u)
#define SCBUART_UART_STOP_BITS_NUM         (2u)
#define SCBUART_UART_OVS_FACTOR            (12u)
#define SCBUART_UART_IRDA_LOW_POWER        (0u)
#define SCBUART_UART_MEDIAN_FILTER_ENABLE  (0u)
#define SCBUART_UART_RETRY_ON_NACK         (0u)
#define SCBUART_UART_IRDA_POLARITY         (0u)
#define SCBUART_UART_DROP_ON_FRAME_ERR     (0u)
#define SCBUART_UART_DROP_ON_PARITY_ERR    (0u)
#define SCBUART_UART_WAKE_ENABLE           (0u)
#define SCBUART_UART_RX_BUFFER_SIZE        (8u)
#define SCBUART_UART_TX_BUFFER_SIZE        (8u)
#define SCBUART_UART_MP_MODE_ENABLE        (0u)
#define SCBUART_UART_MP_ACCEPT_ADDRESS     (0u)
#define SCBUART_UART_MP_RX_ADDRESS         (2u)
#define SCBUART_UART_MP_RX_ADDRESS_MASK    (255u)

#define SCBUART_UART_INTERRUPT_MODE        (2u)

#define SCBUART_UART_INTR_RX_MASK          (0u)
#define SCBUART_UART_INTR_TX_MASK          (0u)

#define SCBUART_UART_RX_TRIGGER_LEVEL      (7u)
#define SCBUART_UART_TX_TRIGGER_LEVEL      (0u)

/* Sources of RX errors */
#define SCBUART_INTR_RX_ERR        (SCBUART_INTR_RX_OVERFLOW    | \
                                             SCBUART_INTR_RX_UNDERFLOW   | \
                                             SCBUART_INTR_RX_FRAME_ERROR | \
                                             SCBUART_INTR_RX_PARITY_ERROR)

/* UART direction enum */
#define SCBUART_UART_RX    (1u)
#define SCBUART_UART_TX    (2u)
#define SCBUART_UART_TX_RX (3u)


/***************************************
*   Conditional Compilation Parameters
****************************************/

#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)

    /* Direction */
    #define SCBUART_RX_DIRECTION           (1u)
    #define SCBUART_TX_DIRECTION           (1u)
    #define SCBUART_UART_RX_DIRECTION      (1u)
    #define SCBUART_UART_TX_DIRECTION      (1u)

    /* Only external RX and TX buffer for uncofigured mode */
    #define SCBUART_INTERNAL_RX_SW_BUFFER   (0u)
    #define SCBUART_INTERNAL_TX_SW_BUFFER   (0u)

    /* Get RX and TX buffer size */
    #define SCBUART_RX_BUFFER_SIZE (SCBUART_rxBufferSize)
    #define SCBUART_TX_BUFFER_SIZE (SCBUART_txBufferSize)

    /* Return true if buffer is provided */
    #define SCBUART_CHECK_RX_SW_BUFFER (NULL != SCBUART_rxBuffer)
    #define SCBUART_CHECK_TX_SW_BUFFER (NULL != SCBUART_txBuffer)

    /* Always provide global variables to support RX and TX buffers */
    #define SCBUART_INTERNAL_RX_SW_BUFFER_CONST    (1u)
    #define SCBUART_INTERNAL_TX_SW_BUFFER_CONST    (1u)

    /* Get wakeup enable option */
    #define SCBUART_SPI_WAKE_ENABLE_CONST  (1u)
    #define SCBUART_CHECK_SPI_WAKE_ENABLE  (0u != SCBUART_scbEnableWake)
    #define SCBUART_UART_WAKE_ENABLE_CONST (1u)

#else

    /* SPI internal RX and TX buffers */
    #define SCBUART_INTERNAL_SPI_RX_SW_BUFFER  (SCBUART_SPI_RX_BUFFER_SIZE > \
                                                                                            SCBUART_FIFO_SIZE)
    #define SCBUART_INTERNAL_SPI_TX_SW_BUFFER  (SCBUART_SPI_TX_BUFFER_SIZE > \
                                                                                            SCBUART_FIFO_SIZE)

    /* UART internal RX and TX buffers */
    #define SCBUART_INTERNAL_UART_RX_SW_BUFFER  (SCBUART_UART_RX_BUFFER_SIZE > \
                                                                                            SCBUART_FIFO_SIZE)
    #define SCBUART_INTERNAL_UART_TX_SW_BUFFER  (SCBUART_UART_TX_BUFFER_SIZE > \
                                                                                            SCBUART_FIFO_SIZE)

    /* SPI Direction */
    #define SCBUART_SPI_RX_DIRECTION (1u)
    #define SCBUART_SPI_TX_DIRECTION (1u)

    /* UART Direction */
    #define SCBUART_UART_RX_DIRECTION (0u != (SCBUART_UART_DIRECTION & SCBUART_UART_RX))
    #define SCBUART_UART_TX_DIRECTION (0u != (SCBUART_UART_DIRECTION & SCBUART_UART_TX))

    /* Direction */
    #define SCBUART_RX_DIRECTION ((SCBUART_SCB_MODE_SPI_CONST_CFG) ? \
                                            (SCBUART_SPI_RX_DIRECTION) : (SCBUART_UART_RX_DIRECTION))

    #define SCBUART_TX_DIRECTION ((SCBUART_SCB_MODE_SPI_CONST_CFG) ? \
                                            (SCBUART_SPI_TX_DIRECTION) : (SCBUART_UART_TX_DIRECTION))

    /* Internal RX and TX buffer: for SPI or UART */
    #if(SCBUART_SCB_MODE_SPI_CONST_CFG)

        /* Internal SPI RX and TX buffer */
        #define SCBUART_INTERNAL_RX_SW_BUFFER  (SCBUART_INTERNAL_SPI_RX_SW_BUFFER)
        #define SCBUART_INTERNAL_TX_SW_BUFFER  (SCBUART_INTERNAL_SPI_TX_SW_BUFFER)

        /* Internal SPI RX and TX buffer size */
        #define SCBUART_RX_BUFFER_SIZE         (SCBUART_SPI_RX_BUFFER_SIZE + 1u)
        #define SCBUART_TX_BUFFER_SIZE         (SCBUART_SPI_TX_BUFFER_SIZE)

        /* Get wakeup enable option */
        #define SCBUART_SPI_WAKE_ENABLE_CONST  (0u != SCBUART_SPI_WAKE_ENABLE)
        #define SCBUART_UART_WAKE_ENABLE_CONST (0u)

    #else

        /* Internal UART RX and TX buffer */
        #define SCBUART_INTERNAL_RX_SW_BUFFER  (SCBUART_INTERNAL_UART_RX_SW_BUFFER)
        #define SCBUART_INTERNAL_TX_SW_BUFFER  (SCBUART_INTERNAL_UART_TX_SW_BUFFER)

        /* Internal UART RX and TX buffer size */
        #define SCBUART_RX_BUFFER_SIZE         (SCBUART_UART_RX_BUFFER_SIZE + 1u)
        #define SCBUART_TX_BUFFER_SIZE         (SCBUART_UART_TX_BUFFER_SIZE)

        /* Get wakeup enable option */
        #define SCBUART_SPI_WAKE_ENABLE_CONST  (0u)
        #define SCBUART_UART_WAKE_ENABLE_CONST (0u != SCBUART_UART_WAKE_ENABLE)
    #endif /* (SCBUART_SCB_MODE_SPI_CONST_CFG) */

    /* Internal RX and TX buffer: for SPI or UART. Used in conditional compilation check */
    #define SCBUART_CHECK_RX_SW_BUFFER (SCBUART_INTERNAL_RX_SW_BUFFER)
    #define SCBUART_CHECK_TX_SW_BUFFER (SCBUART_INTERNAL_TX_SW_BUFFER)

    /* Provide global variables to support RX and TX buffers */
    #define SCBUART_INTERNAL_RX_SW_BUFFER_CONST    (SCBUART_INTERNAL_RX_SW_BUFFER)
    #define SCBUART_INTERNAL_TX_SW_BUFFER_CONST    (SCBUART_INTERNAL_TX_SW_BUFFER)

    /* Wakeup for SPI */
    #define SCBUART_CHECK_SPI_WAKE_ENABLE  (SCBUART_SPI_WAKE_ENABLE_CONST)

#endif /* End (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */

/* Bootloader communication interface enable: NOT supported yet */
#define SCBUART_SPI_BTLDR_COMM_ENABLED   ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_SCBUART) || \
                                                    (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

#define SCBUART_UART_BTLDR_COMM_ENABLED   ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_SCBUART) || \
                                                    (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))


/***************************************
*       Type Definitions
***************************************/

/* SCBUART_SPI_INIT_STRUCT */
typedef struct
{
    uint32 mode;
    uint32 submode;
    uint32 sclkMode;
    uint32 oversample;
    uint32 enableMedianFilter;
    uint32 enableLateSampling;
    uint32 enableWake;
    uint32 rxDataBits;
    uint32 txDataBits;
    uint32 bitOrder;
    uint32 transferSeperation;
    uint32 rxBufferSize;
    uint8* rxBuffer;
    uint32 txBufferSize;
    uint8* txBuffer;
    uint32 enableInterrupt;
    uint32 rxInterruptMask;
    uint32 rxTriggerLevel;
    uint32 txInterruptMask;
    uint32 txTriggerLevel;
} SCBUART_SPI_INIT_STRUCT;

/* SCBUART_UART_INIT_STRUCT */
typedef struct
{
    uint32 mode;
    uint32 direction;
    uint32 dataBits;
    uint32 parity;
    uint32 stopBits;
    uint32 oversample;
    uint32 enableIrdaLowPower;
    uint32 enableMedianFilter;
    uint32 enableRetryNack;
    uint32 enableInvertedRx;
    uint32 dropOnParityErr;
    uint32 dropOnFrameErr;
    uint32 enableWake;
    uint32 rxBufferSize;
    uint8* rxBuffer;
    uint32 txBufferSize;
    uint8* txBuffer;
    uint32 enableMultiproc;
    uint32 multiprocAcceptAddr;
    uint32 multiprocAddr;
    uint32 multiprocAddrMask;
    uint32 enableInterrupt;
    uint32 rxInterruptMask;
    uint32 rxTriggerLevel;
    uint32 txInterruptMask;
    uint32 txTriggerLevel;
} SCBUART_UART_INIT_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

/* SPI specific functions */
#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    void SCBUART_SpiInit(const SCBUART_SPI_INIT_STRUCT *config);
#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */

#if(SCBUART_SCB_MODE_SPI_INC)
    void SCBUART_SpiSetActiveSlaveSelect(uint32 activeSelect);
#endif /* (SCBUART_SCB_MODE_SPI_INC) */

/* UART specific functions */
#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    void SCBUART_UartInit(const SCBUART_UART_INIT_STRUCT *config);
#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */

#if(SCBUART_SCB_MODE_UART_INC)
    void SCBUART_UartSetRxAddress(uint32 address);
    void SCBUART_UartSetRxAddressMask(uint32 addressMask);
#endif /* (SCBUART_SCB_MODE_UART_INC) */

/* UART RX direction APIs */
#if(SCBUART_UART_RX_DIRECTION)
    uint32 SCBUART_UartGetChar(void);
    uint32 SCBUART_UartGetByte(void);
#endif /* (SCBUART_UART_RX_DIRECTION) */

/* UART TX direction APIs */
#if(SCBUART_UART_TX_DIRECTION)
    #define SCBUART_UartPutChar(ch)    SCBUART_SpiUartWriteTxData((uint32)(ch))
    void SCBUART_UartPutString(const char8 string[]);
    void SCBUART_UartPutCRLF(uint32 txDataByte);
#endif /* (SCBUART_UART_TX_DIRECTION) */

/* Common APIs Rx direction */
#if(SCBUART_RX_DIRECTION)
    uint32 SCBUART_SpiUartReadRxData(void);
    uint32 SCBUART_SpiUartGetRxBufferSize(void);
    void   SCBUART_SpiUartClearRxBuffer(void);
#endif /* (SCBUART_RX_DIRECTION) */

/* Common APIs Tx direction */
#if(SCBUART_TX_DIRECTION)
    void   SCBUART_SpiUartWriteTxData(uint32 txData);
    void   SCBUART_SpiUartPutArray(const uint8 wrBuf[], uint32 count);
    void   SCBUART_SpiUartClearTxBuffer(void);
    uint32 SCBUART_SpiUartGetTxBufferSize(void);
#endif /* (SCBUART_TX_DIRECTION) */

CY_ISR_PROTO(SCBUART_SPI_UART_ISR);

#if(SCBUART_UART_RX_WAKEUP_IRQ)
    CY_ISR_PROTO(SCBUART_UART_WAKEUP_ISR);
#endif /* (SCBUART_UART_RX_WAKEUP_IRQ) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SCBUART_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void SCBUART_SpiCyBtldrCommStart(void);
    void SCBUART_SpiCyBtldrCommStop (void);
    void SCBUART_SpiCyBtldrCommReset(void);
    cystatus SCBUART_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SCBUART_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SCBUART_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SCBUART_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void SCBUART_UartCyBtldrCommStart(void);
    void SCBUART_UartCyBtldrCommStop (void);
    void SCBUART_UartCyBtldrCommReset(void);
    cystatus SCBUART_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SCBUART_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SCBUART_UART_BTLDR_COMM_ENABLED) */


/***************************************
*     Buffer Access Macro Definitions
***************************************/

#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    /* RX direction */
    void   SCBUART_PutWordInRxBuffer  (uint32 idx, uint32 rxDataByte);
    uint32 SCBUART_GetWordFromRxBuffer(uint32 idx);

    /* TX direction */
    void   SCBUART_PutWordInTxBuffer  (uint32 idx, uint32 txDataByte);
    uint32 SCBUART_GetWordFromTxBuffer(uint32 idx);

#else

    /* RX direction */
    #if(SCBUART_INTERNAL_RX_SW_BUFFER_CONST)
        #define SCBUART_PutWordInRxBuffer(idx, rxDataByte) \
                do{                                                 \
                    SCBUART_rxBufferInternal[(idx)] = ((uint8) (rxDataByte)); \
                }while(0)

        #define SCBUART_GetWordFromRxBuffer(idx) SCBUART_rxBufferInternal[(idx)]

    #endif /* (SCBUART_INTERNAL_RX_SW_BUFFER_CONST) */

    /* TX direction */
    #if(SCBUART_INTERNAL_TX_SW_BUFFER_CONST)
        #define SCBUART_PutWordInTxBuffer(idx, txDataByte) \
                    do{                                             \
                        SCBUART_txBufferInternal[(idx)] = ((uint8) (txDataByte)); \
                    }while(0)

        #define SCBUART_GetWordFromTxBuffer(idx) SCBUART_txBufferInternal[(idx)]

    #endif /* (SCBUART_INTERNAL_TX_SW_BUFFER_CONST) */

#endif /* (SCBUART_TX_SW_BUFFER_ENABLE) */


/***************************************
*         SPI API Constants
***************************************/

/* SPI mode enum */
#define SCBUART_SPI_SLAVE  (0u)
#define SCBUART_SPI_MASTER (1u)

/* SPI sub mode enum */
#define SCBUART_SPI_MODE_MOTOROLA      (0x00u)
#define SCBUART_SPI_MODE_TI_COINCIDES  (0x01u)
#define SCBUART_SPI_MODE_TI_PRECEDES   (0x11u)
#define SCBUART_SPI_MODE_NATIONAL      (0x02u)
#define SCBUART_SPI_MODE_MASK          (0x03u)
#define SCBUART_SPI_MODE_TI_PRECEDES_MASK  (0x10u)

/* SPI phase and polarity mode enum */
#define SCBUART_SPI_SCLK_CPHA0_CPOL0   (0x00u)
#define SCBUART_SPI_SCLK_CPHA0_CPOL1   (0x02u)
#define SCBUART_SPI_SCLK_CPHA1_CPOL0   (0x01u)
#define SCBUART_SPI_SCLK_CPHA1_CPOL1   (0x03u)

/* SPI bits order enum */
#define SCBUART_BITS_ORDER_LSB_FIRST   (0u)
#define SCBUART_BITS_ORDER_MSB_FIRST   (1u)

/* SPI transfer separation enum */
#define SCBUART_SPI_TRANSFER_SEPARATED     (0u)
#define SCBUART_SPI_TRANSFER_CONTINUOUS    (1u)

/* SPI master active slave select constants for SCBUART_SpiSetActiveSlaveSelect() */
#define SCBUART_SPIM_ACTIVE_SS0    (0x00u)
#define SCBUART_SPIM_ACTIVE_SS1    (0x01u)
#define SCBUART_SPIM_ACTIVE_SS2    (0x02u)
#define SCBUART_SPIM_ACTIVE_SS3    (0x03u)


/***************************************
*         UART API Constants
***************************************/

/* UART sub-modes enum */
#define SCBUART_UART_MODE_STD          (0u)
#define SCBUART_UART_MODE_SMARTCARD    (1u)
#define SCBUART_UART_MODE_IRDA         (2u)

/* UART direction enum */
#define SCBUART_UART_RX    (1u)
#define SCBUART_UART_TX    (2u)
#define SCBUART_UART_TX_RX (3u)

/* UART parity enum */
#define SCBUART_UART_PARITY_EVEN   (0u)
#define SCBUART_UART_PARITY_ODD    (1u)
#define SCBUART_UART_PARITY_NONE   (2u)

/* UART stop bits enum */
#define SCBUART_UART_STOP_BITS_1   (2u)
#define SCBUART_UART_STOP_BITS_1_5 (3u)
#define SCBUART_UART_STOP_BITS_2   (4u)

/* UART IrDA low power OVS enum */
#define SCBUART_UART_IRDA_LP_OVS16     (16u)
#define SCBUART_UART_IRDA_LP_OVS32     (32u)
#define SCBUART_UART_IRDA_LP_OVS48     (48u)
#define SCBUART_UART_IRDA_LP_OVS96     (96u)
#define SCBUART_UART_IRDA_LP_OVS192    (192u)
#define SCBUART_UART_IRDA_LP_OVS768    (768u)
#define SCBUART_UART_IRDA_LP_OVS1536   (1536u)

/* Uart MP: mark (address) and space (data) bit definitions */
#define SCBUART_UART_MP_MARK       (0x100u)
#define SCBUART_UART_MP_SPACE      (0x000u)


/***************************************
*     Vars with External Linkage
***************************************/

#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    extern const SCBUART_SPI_INIT_STRUCT  SCBUART_configSpi;
    extern const SCBUART_UART_INIT_STRUCT SCBUART_configUart;
#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*    Specific SPI Macro Definitions
***************************************/

#define SCBUART_GET_SPI_INTR_SLAVE_MASK(sourceMask)  ((sourceMask) & SCBUART_INTR_SLAVE_SPI_BUS_ERROR)
#define SCBUART_GET_SPI_INTR_MASTER_MASK(sourceMask) ((sourceMask) & SCBUART_INTR_MASTER_SPI_DONE)
#define SCBUART_GET_SPI_INTR_RX_MASK(sourceMask) \
                                             ((sourceMask) & (uint32) ~SCBUART_INTR_SLAVE_SPI_BUS_ERROR)

#define SCBUART_GET_SPI_INTR_TX_MASK(sourceMask) \
                                             ((sourceMask) & (uint32) ~SCBUART_INTR_MASTER_SPI_DONE)


/***************************************
*    Specific UART Macro Definitions
***************************************/

#define SCBUART_UART_GET_CTRL_OVS_IRDA_LP(oversample) \
        ((SCBUART_UART_IRDA_LP_OVS16   == (oversample)) ? SCBUART_CTRL_OVS_IRDA_LP_OVS16 : \
         ((SCBUART_UART_IRDA_LP_OVS32   == (oversample)) ? SCBUART_CTRL_OVS_IRDA_LP_OVS32 : \
          ((SCBUART_UART_IRDA_LP_OVS48   == (oversample)) ? SCBUART_CTRL_OVS_IRDA_LP_OVS48 : \
           ((SCBUART_UART_IRDA_LP_OVS96   == (oversample)) ? SCBUART_CTRL_OVS_IRDA_LP_OVS96 : \
            ((SCBUART_UART_IRDA_LP_OVS192  == (oversample)) ? SCBUART_CTRL_OVS_IRDA_LP_OVS192 : \
             ((SCBUART_UART_IRDA_LP_OVS768  == (oversample)) ? SCBUART_CTRL_OVS_IRDA_LP_OVS768 : \
              ((SCBUART_UART_IRDA_LP_OVS1536 == (oversample)) ? SCBUART_CTRL_OVS_IRDA_LP_OVS1536 : \
                                                                          SCBUART_CTRL_OVS_IRDA_LP_OVS16)))))))

#define SCBUART_GET_UART_RX_CTRL_ENABLED(direction) ((0u != (SCBUART_UART_RX & (direction))) ? \
                                                                    (SCBUART_RX_CTRL_ENABLED) : (0u))

#define SCBUART_GET_UART_TX_CTRL_ENABLED(direction) ((0u != (SCBUART_UART_TX & (direction))) ? \
                                                                    (SCBUART_TX_CTRL_ENABLED) : (0u))


/***************************************
*        SPI Register Settings
***************************************/

#define SCBUART_CTRL_SPI      (SCBUART_CTRL_MODE_SPI)
#define SCBUART_SPI_RX_CTRL   (SCBUART_RX_CTRL_ENABLED)
#define SCBUART_SPI_TX_CTRL   (SCBUART_TX_CTRL_ENABLED)


/***************************************
*       SPI Init Register Settings
***************************************/

#if(SCBUART_SCB_MODE_SPI_CONST_CFG)

    /* SPI Configuration */
    #define SCBUART_SPI_DEFAULT_CTRL \
                    (SCBUART_GET_CTRL_OVS(SCBUART_SPI_OVS_FACTOR)         | \
                     SCBUART_GET_CTRL_EC_AM_MODE(SCBUART_SPI_WAKE_ENABLE) | \
                     SCBUART_CTRL_SPI)

    #define SCBUART_SPI_DEFAULT_SPI_CTRL \
                    (SCBUART_GET_SPI_CTRL_CONTINUOUS    (SCBUART_SPI_TRANSFER_SEPARATION)       | \
                     SCBUART_GET_SPI_CTRL_SELECT_PRECEDE(SCBUART_SPI_SUB_MODE &                   \
                                                                  SCBUART_SPI_MODE_TI_PRECEDES_MASK)     | \
                     SCBUART_GET_SPI_CTRL_SCLK_MODE     (SCBUART_SPI_CLOCK_MODE)                | \
                     SCBUART_GET_SPI_CTRL_LATE_MISO_SAMPLE(SCBUART_SPI_LATE_MISO_SAMPLE_ENABLE) | \
                     SCBUART_GET_SPI_CTRL_SUB_MODE      (SCBUART_SPI_SUB_MODE)                  | \
                     SCBUART_GET_SPI_CTRL_MASTER_MODE   (SCBUART_SPI_MODE))

    /* RX direction */
    #define SCBUART_SPI_DEFAULT_RX_CTRL \
                    (SCBUART_GET_RX_CTRL_DATA_WIDTH(SCBUART_SPI_RX_DATA_BITS_NUM)     | \
                     SCBUART_GET_RX_CTRL_BIT_ORDER (SCBUART_SPI_BITS_ORDER)           | \
                     SCBUART_GET_RX_CTRL_MEDIAN    (SCBUART_SPI_MEDIAN_FILTER_ENABLE) | \
                     SCBUART_SPI_RX_CTRL)

    #define SCBUART_SPI_DEFAULT_RX_FIFO_CTRL \
                    SCBUART_GET_RX_FIFO_CTRL_TRIGGER_LEVEL(SCBUART_SPI_RX_TRIGGER_LEVEL)

    /* TX direction */
    #define SCBUART_SPI_DEFAULT_TX_CTRL \
                    (SCBUART_GET_TX_CTRL_DATA_WIDTH(SCBUART_SPI_TX_DATA_BITS_NUM) | \
                     SCBUART_GET_TX_CTRL_BIT_ORDER (SCBUART_SPI_BITS_ORDER)       | \
                     SCBUART_SPI_TX_CTRL)

    #define SCBUART_SPI_DEFAULT_TX_FIFO_CTRL \
                    SCBUART_GET_TX_FIFO_CTRL_TRIGGER_LEVEL(SCBUART_SPI_TX_TRIGGER_LEVEL)

    /* Interrupt sources */
    #define SCBUART_SPI_DEFAULT_INTR_SPI_EC_MASK   (SCBUART_NO_INTR_SOURCES)

    #define SCBUART_SPI_DEFAULT_INTR_I2C_EC_MASK   (SCBUART_NO_INTR_SOURCES)
    #define SCBUART_SPI_DEFAULT_INTR_SLAVE_MASK \
                    (SCBUART_SPI_INTR_RX_MASK & SCBUART_INTR_SLAVE_SPI_BUS_ERROR)

    #define SCBUART_SPI_DEFAULT_INTR_MASTER_MASK \
                    (SCBUART_SPI_INTR_TX_MASK & SCBUART_INTR_MASTER_SPI_DONE)

    #define SCBUART_SPI_DEFAULT_INTR_RX_MASK \
                    (SCBUART_SPI_INTR_RX_MASK & (uint32) ~SCBUART_INTR_SLAVE_SPI_BUS_ERROR)

    #define SCBUART_SPI_DEFAULT_INTR_TX_MASK \
                    (SCBUART_SPI_INTR_TX_MASK & (uint32) ~SCBUART_INTR_MASTER_SPI_DONE)

#endif /* (SCBUART_SCB_MODE_SPI_CONST_CFG) */


/***************************************
*        UART Register Settings
***************************************/

#define SCBUART_CTRL_UART      (SCBUART_CTRL_MODE_UART)
#define SCBUART_UART_RX_CTRL   (SCBUART_RX_CTRL_LSB_FIRST) /* LSB for UART goes first */
#define SCBUART_UART_TX_CTRL   (SCBUART_TX_CTRL_LSB_FIRST) /* LSB for UART goes first */


/***************************************
*      UART Init Register Settings
***************************************/

#if(SCBUART_SCB_MODE_UART_CONST_CFG)

    /* UART configuration */
    #if(SCBUART_UART_MODE_IRDA == SCBUART_UART_SUB_MODE)

        #define SCBUART_DEFAULT_CTRL_OVS   ((0u != SCBUART_UART_IRDA_LOW_POWER) ?              \
                                (SCBUART_UART_GET_CTRL_OVS_IRDA_LP(SCBUART_UART_OVS_FACTOR)) : \
                                (SCBUART_CTRL_OVS_IRDA_OVS16))

    #else

        #define SCBUART_DEFAULT_CTRL_OVS   SCBUART_GET_CTRL_OVS(SCBUART_UART_OVS_FACTOR)

    #endif /* (SCBUART_UART_MODE_IRDA == SCBUART_UART_SUB_MODE) */

    #define SCBUART_UART_DEFAULT_CTRL \
                                (SCBUART_GET_CTRL_ADDR_ACCEPT(SCBUART_UART_MP_ACCEPT_ADDRESS) | \
                                 SCBUART_DEFAULT_CTRL_OVS                                              | \
                                 SCBUART_CTRL_UART)

    #define SCBUART_UART_DEFAULT_UART_CTRL \
                                    (SCBUART_GET_UART_CTRL_MODE(SCBUART_UART_SUB_MODE))

    /* RX direction */
    #define SCBUART_UART_DEFAULT_RX_CTRL_PARITY \
                                ((SCBUART_UART_PARITY_NONE != SCBUART_UART_PARITY_TYPE) ?      \
                                  (SCBUART_GET_UART_RX_CTRL_PARITY(SCBUART_UART_PARITY_TYPE) | \
                                   SCBUART_UART_RX_CTRL_PARITY_ENABLED) : (0u))

    #define SCBUART_UART_DEFAULT_UART_RX_CTRL \
                    (SCBUART_GET_UART_RX_CTRL_MODE(SCBUART_UART_STOP_BITS_NUM)                    | \
                     SCBUART_GET_UART_RX_CTRL_POLARITY(SCBUART_UART_IRDA_POLARITY)                | \
                     SCBUART_GET_UART_RX_CTRL_MP_MODE(SCBUART_UART_MP_MODE_ENABLE)                | \
                     SCBUART_GET_UART_RX_CTRL_DROP_ON_PARITY_ERR(SCBUART_UART_DROP_ON_PARITY_ERR) | \
                     SCBUART_GET_UART_RX_CTRL_DROP_ON_FRAME_ERR(SCBUART_UART_DROP_ON_FRAME_ERR)   | \
                     SCBUART_UART_DEFAULT_RX_CTRL_PARITY)

    #define SCBUART_UART_DEFAULT_RX_CTRL \
                                (SCBUART_GET_RX_CTRL_DATA_WIDTH(SCBUART_UART_DATA_BITS_NUM)        | \
                                 SCBUART_GET_RX_CTRL_MEDIAN    (SCBUART_UART_MEDIAN_FILTER_ENABLE) | \
                                 SCBUART_GET_UART_RX_CTRL_ENABLED(SCBUART_UART_DIRECTION))

    #define SCBUART_UART_DEFAULT_RX_FIFO_CTRL \
                                SCBUART_GET_RX_FIFO_CTRL_TRIGGER_LEVEL(SCBUART_UART_RX_TRIGGER_LEVEL)

    #define SCBUART_UART_DEFAULT_RX_MATCH_REG  ((0u != SCBUART_UART_MP_MODE_ENABLE) ?          \
                                (SCBUART_GET_RX_MATCH_ADDR(SCBUART_UART_MP_RX_ADDRESS) | \
                                 SCBUART_GET_RX_MATCH_MASK(SCBUART_UART_MP_RX_ADDRESS_MASK)) : (0u))

    /* TX direction */
    #define SCBUART_UART_DEFAULT_TX_CTRL_PARITY (SCBUART_UART_DEFAULT_RX_CTRL_PARITY)

    #define SCBUART_UART_DEFAULT_UART_TX_CTRL \
                                (SCBUART_GET_UART_TX_CTRL_MODE(SCBUART_UART_STOP_BITS_NUM)       | \
                                 SCBUART_GET_UART_TX_CTRL_RETRY_NACK(SCBUART_UART_RETRY_ON_NACK) | \
                                 SCBUART_UART_DEFAULT_TX_CTRL_PARITY)

    #define SCBUART_UART_DEFAULT_TX_CTRL \
                                (SCBUART_GET_TX_CTRL_DATA_WIDTH(SCBUART_UART_DATA_BITS_NUM) | \
                                 SCBUART_GET_UART_TX_CTRL_ENABLED(SCBUART_UART_DIRECTION))

    #define SCBUART_UART_DEFAULT_TX_FIFO_CTRL \
                                SCBUART_GET_TX_FIFO_CTRL_TRIGGER_LEVEL(SCBUART_UART_TX_TRIGGER_LEVEL)

    /* Interrupt sources */
    #define SCBUART_UART_DEFAULT_INTR_I2C_EC_MASK  (SCBUART_NO_INTR_SOURCES)
    #define SCBUART_UART_DEFAULT_INTR_SPI_EC_MASK  (SCBUART_NO_INTR_SOURCES)
    #define SCBUART_UART_DEFAULT_INTR_SLAVE_MASK   (SCBUART_NO_INTR_SOURCES)
    #define SCBUART_UART_DEFAULT_INTR_MASTER_MASK  (SCBUART_NO_INTR_SOURCES)
    #define SCBUART_UART_DEFAULT_INTR_RX_MASK      (SCBUART_UART_INTR_RX_MASK)
    #define SCBUART_UART_DEFAULT_INTR_TX_MASK      (SCBUART_UART_INTR_TX_MASK)

#endif /* (SCBUART_SCB_MODE_UART_CONST_CFG) */

#endif /* CY_SCB_SPI_UART_SCBUART_H */


/* [] END OF FILE */
