/*******************************************************************************
* File Name: myUART_PM.c
* Version 2.30
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "myUART.h"


/***************************************
* Local data allocation
***************************************/

static myUART_BACKUP_STRUCT  myUART_backup =
{
    /* enableState - disabled */
    0u,
};



/*******************************************************************************
* Function Name: myUART_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  myUART_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void myUART_SaveConfig(void)
{
    #if (CY_UDB_V0)

        #if(myUART_CONTROL_REG_REMOVED == 0u)
            myUART_backup.cr = myUART_CONTROL_REG;
        #endif /* End myUART_CONTROL_REG_REMOVED */

        #if( (myUART_RX_ENABLED) || (myUART_HD_ENABLED) )
            myUART_backup.rx_period = myUART_RXBITCTR_PERIOD_REG;
            myUART_backup.rx_mask = myUART_RXSTATUS_MASK_REG;
            #if (myUART_RXHW_ADDRESS_ENABLED)
                myUART_backup.rx_addr1 = myUART_RXADDRESS1_REG;
                myUART_backup.rx_addr2 = myUART_RXADDRESS2_REG;
            #endif /* End myUART_RXHW_ADDRESS_ENABLED */
        #endif /* End myUART_RX_ENABLED | myUART_HD_ENABLED*/

        #if(myUART_TX_ENABLED)
            #if(myUART_TXCLKGEN_DP)
                myUART_backup.tx_clk_ctr = myUART_TXBITCLKGEN_CTR_REG;
                myUART_backup.tx_clk_compl = myUART_TXBITCLKTX_COMPLETE_REG;
            #else
                myUART_backup.tx_period = myUART_TXBITCTR_PERIOD_REG;
            #endif /*End myUART_TXCLKGEN_DP */
            myUART_backup.tx_mask = myUART_TXSTATUS_MASK_REG;
        #endif /*End myUART_TX_ENABLED */


    #else /* CY_UDB_V1 */

        #if(myUART_CONTROL_REG_REMOVED == 0u)
            myUART_backup.cr = myUART_CONTROL_REG;
        #endif /* End myUART_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: myUART_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  myUART_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void myUART_RestoreConfig(void)
{

    #if (CY_UDB_V0)

        #if(myUART_CONTROL_REG_REMOVED == 0u)
            myUART_CONTROL_REG = myUART_backup.cr;
        #endif /* End myUART_CONTROL_REG_REMOVED */

        #if( (myUART_RX_ENABLED) || (myUART_HD_ENABLED) )
            myUART_RXBITCTR_PERIOD_REG = myUART_backup.rx_period;
            myUART_RXSTATUS_MASK_REG = myUART_backup.rx_mask;
            #if (myUART_RXHW_ADDRESS_ENABLED)
                myUART_RXADDRESS1_REG = myUART_backup.rx_addr1;
                myUART_RXADDRESS2_REG = myUART_backup.rx_addr2;
            #endif /* End myUART_RXHW_ADDRESS_ENABLED */
        #endif  /* End (myUART_RX_ENABLED) || (myUART_HD_ENABLED) */

        #if(myUART_TX_ENABLED)
            #if(myUART_TXCLKGEN_DP)
                myUART_TXBITCLKGEN_CTR_REG = myUART_backup.tx_clk_ctr;
                myUART_TXBITCLKTX_COMPLETE_REG = myUART_backup.tx_clk_compl;
            #else
                myUART_TXBITCTR_PERIOD_REG = myUART_backup.tx_period;
            #endif /*End myUART_TXCLKGEN_DP */
            myUART_TXSTATUS_MASK_REG = myUART_backup.tx_mask;
        #endif /*End myUART_TX_ENABLED */

    #else /* CY_UDB_V1 */

        #if(myUART_CONTROL_REG_REMOVED == 0u)
            myUART_CONTROL_REG = myUART_backup.cr;
        #endif /* End myUART_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: myUART_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration. Should be called
*  just prior to entering sleep.
*
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  myUART_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void myUART_Sleep(void)
{

    #if(myUART_RX_ENABLED || myUART_HD_ENABLED)
        if((myUART_RXSTATUS_ACTL_REG  & myUART_INT_ENABLE) != 0u)
        {
            myUART_backup.enableState = 1u;
        }
        else
        {
            myUART_backup.enableState = 0u;
        }
    #else
        if((myUART_TXSTATUS_ACTL_REG  & myUART_INT_ENABLE) !=0u)
        {
            myUART_backup.enableState = 1u;
        }
        else
        {
            myUART_backup.enableState = 0u;
        }
    #endif /* End myUART_RX_ENABLED || myUART_HD_ENABLED*/

    myUART_Stop();
    myUART_SaveConfig();
}


/*******************************************************************************
* Function Name: myUART_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  myUART_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void myUART_Wakeup(void)
{
    myUART_RestoreConfig();
    #if( (myUART_RX_ENABLED) || (myUART_HD_ENABLED) )
        myUART_ClearRxBuffer();
    #endif /* End (myUART_RX_ENABLED) || (myUART_HD_ENABLED) */
    #if(myUART_TX_ENABLED || myUART_HD_ENABLED)
        myUART_ClearTxBuffer();
    #endif /* End myUART_TX_ENABLED || myUART_HD_ENABLED */

    if(myUART_backup.enableState != 0u)
    {
        myUART_Enable();
    }
}


/* [] END OF FILE */
