/**
 * @file main.c
 * @author  Reiner Wehner 
 * @date    12.05.2015 - first implement
 *
 * @section LICENSE
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details at
 * https://www.gnu.org/copyleft/gpl.html
 *
 * @section example for use rotary encoder with TCPWM-QuadDec Component
 *          without debouncing
 * @todo
 *
 * @version 1.0
 */
				
#include <project.h>
#include <stdio.h>

#define WELCOME1 "RE not debounced 1"
#define WELCOME2 "RW 12052015"


#define INITIAL_COUNTER 0x8000     //TCPMW InitialCounter
/*--------rotary struct----------*/
typedef struct {
    uint32 counterValue;           //actual counter
    volatile uint8 switchPressed;  //status of encoder switch
    uint32 direction;              //encoder direction
} ENCODER;

ENCODER myEncoder = {              
    .counterValue = 0,
    .switchPressed = 0,
    .direction = 0,
};

CY_ISR(isrEncoderSwich){
   myEncoder.switchPressed = 1;    //set encoder switch flag
}

int main(){

    //Starts the Component
    LCD_Char_Start();              //start lcd component 
    QuadDec_Start();               //start TCPWM-QuadDec component
    QuadDec_TriggerCommand(QuadDec_MASK, QuadDec_CMD_RELOAD); //see http://www.cypress.com/?app=forum&id=4749&rID=97375
    QuadDec_SetQDMode(QuadDec_MODE_X1); //initial mode
    
    //isr for Encoder Swich
    isrPinSW_StartEx(isrEncoderSwich);
    
    /*Welcome, version, date*/
    LCD_Char_PrintString(WELCOME1);
    LCD_Char_Position(1u, 0);   
    LCD_Char_PrintString(WELCOME2);
    CyDelay(3000u);
    LCD_Char_ClearDisplay();   
    
    CyGlobalIntEnable; /* Uncomment this line to enable global interrupts. */
    
    uint8 encoderMode = 0;  //actual encoder mode for test all modes 
    uint32 myCounter = 0;   //counts  (encoder Counter - initial Counter value)
    
    myEncoder.switchPressed = 0; //ButtonSW switch to Vss -> isr is fire on reset
    
    while(1){
        /*Encoder*/
        myEncoder.counterValue = QuadDec_ReadCounter();  //read counter
        myCounter = myEncoder.counterValue - INITIAL_COUNTER;  //set to 0 based counter
        myEncoder.direction = QuadDec_ReadStatus() & 1; /* read direction
                                                           bit0 = QuadDec_STATUS_DOWN
                                                           bit1 = QuadDec_STATUS_RUNNING
                                                           direction ist _STATUS_DOWN see TRM PSoC 4200 S. 176
                                                        */ 
          
        if (myEncoder.switchPressed){  //switch encoder mode ONLY for find correct mode
            encoderMode++;             //increment encoder mode      
            if (3 == encoderMode) {    //only 3 different modes
               encoderMode = 0;        
            }  
            switch(encoderMode){       //set the new encoder mode to component 
            case 0: QuadDec_SetQDMode(QuadDec_MODE_X1); break;  //set mode 1 to component
            case 1: QuadDec_SetQDMode(QuadDec_MODE_X2); break;  //set mode 2 to component
            case 2: QuadDec_SetQDMode(QuadDec_MODE_X4); break;  //set mode 3 to component
            }
            myEncoder.switchPressed = 0;               //reset encoder switch flag
            myEncoder.counterValue = INITIAL_COUNTER;  //set counter value to initial counter value

        }

       //print encoderCounterValue
        LCD_Char_Position(0u, 0u);                     //set first row, first col
        LCD_Char_PrintString("enc:");                  
        LCD_Char_PrintNumber(myEncoder.counterValue);  //print actual counter value
        LCD_Char_PrintString(" em:");        
        LCD_Char_PrintNumber(1 << encoderMode);        //encoderMode is 0,1,2 but encoder mode is 1,2,4
        LCD_Char_PrintString(" dir:");
        LCD_Char_PutChar((myEncoder.direction == QuadDec__COUNT_DOWN)?'-':'+');  //print component encoder mode
         
        LCD_Char_Position(1u, 0u);   
        LCD_Char_PrintString("counts:");
        LCD_Char_PrintNumber(myCounter);               //print actual encoder counter -  INITIAL_COUNTER

    }
}
/* [] END OF FILE */
